@@ -1,4 +1,4 @@
-from typing import Optional, Union, Tuple, List
+from typing import Optional, Union, Tuple
 import torch
 import numpy as np
 import gymnasium as gym
@@ -33,7 +33,7 @@ class GymEnv(BaseEnvTrait):
         if self._normalize_act and self.gym_env is not None:
             assert isinstance(
                 self.gym_env.action_space, Box
-            ), f"only box action space can be normalized, get type {type(self.gym_env.action_space)}"
+            ), f"only box action space can be normalized, get type {type(self.gym_env.action_space)}"  # noqa: E501
         assert self.gym_env is not None, "self.gym must be a gym env, not None"
 
     def reset(self):
@@ -47,7 +47,9 @@ class GymEnv(BaseEnvTrait):
             and isinstance(self.gym_env.action_space, Box)
             and (isinstance(action, np.ndarray) or isinstance(action, torch.Tensor))
         ):
-            action = scale_actions(action, self.gym_env.action_space.low, self.gym_env.action_space.high)
+            action = scale_actions(
+                action, self.gym_env.action_space.low, self.gym_env.action_space.high
+            )
         observation, reward, terminated, truncated, info = self.gym_env.step(action)
         return (
             observation,
@@ -89,7 +91,7 @@ class CartPoleEnv(GymEnv):
         return ()
 
     @property
-    def action_n(self) -> int:
+    def action_n(self) -> np.int64:
         assert isinstance(self.gym_env.action_space, Discrete)
         return self.gym_env.action_space.n
 
@@ -98,7 +100,9 @@ class MountainCarContinuousEnv(GymEnv):
     def __init__(self, *, viz: bool = False, seed: int = 19970314) -> None:
         super().__init__(normalize_act=False, viz=viz, seed=seed)
         if viz:
-            self.gym_env: gym.Env = gym.make("MountainCarContinuous-v0", render_mode="human")
+            self.gym_env: gym.Env = gym.make(
+                "MountainCarContinuous-v0", render_mode="human"
+            )
         else:
             self.gym_env: gym.Env = gym.make("MountainCarContinuous-v0")
 
@@ -108,8 +112,8 @@ class MountainCarContinuousEnv(GymEnv):
         return self.gym_env.action_space.shape
 
     @property
-    def action_n(self) -> int:
-        return 0
+    def action_n(self) -> np.int64:
+        return np.int64(0)
 
 
 class PendulumEnv(GymEnv):
@@ -128,12 +132,14 @@ class PendulumEnv(GymEnv):
         return self.gym_env.action_space.shape
 
     @property
-    def action_n(self) -> int:
-        return 0
+    def action_n(self) -> np.int64:
+        return np.int64(0)
 
 
 class LunarLanderEnv(GymEnv):
-    def __init__(self, *, continuous: bool = True, viz: bool = False, seed: int = 19970314) -> None:
+    def __init__(
+        self, *, continuous: bool = True, viz: bool = False, seed: int = 19970314
+    ) -> None:
         super().__init__(normalize_act=False, viz=viz, seed=seed)
         self.continuous = continuous
         if viz:
@@ -156,11 +162,48 @@ class LunarLanderEnv(GymEnv):
             return ()
 
     @property
-    def action_n(self) -> int:
+    def action_n(self) -> np.int64:
         if self.continuous:
-            return 0
+            return np.int64(0)
         else:
             assert isinstance(
                 self.gym_env.action_space, Discrete
-            ), "LunarLander enabled continuous action space, action_n is not defined for continuous action"
+            ), "LunarLander enabled continuous action space, action_n is not defined for continuous action"  # noqa: E501
             return self.gym_env.action_space.n
+
+
+class TorchCartPoleEnv(CartPoleEnv):
+    def __init__(
+        self,
+        *,
+        viz: bool,
+        seed: int = 19970314,
+        device: torch.device = torch.device("cpu"),
+    ) -> None:
+        super().__init__(viz=viz, seed=seed)
+        self.device = device
+
+    def reset(self):
+        observation, info = super().reset()
+        return torch.Tensor(observation), info
+
+    def step(self, action: torch.Tensor):
+        observation, reward, done, info = super().step(action.item())
+        return (
+            torch.tensor(observation, device=self.device),
+            torch.tensor([reward], device=self.device),
+            torch.tensor([done], dtype=torch.int, device=self.device),
+            info,
+        )
+
+    def sample_action(self):
+        assert self.gym_env is not None, "self.gym must be a gym env, not None"
+        if self._normalize_act and isinstance(self.gym_env.action_space, Box):
+            return unscale_actions(
+                self.gym_env.action_space.sample(),
+                self.gym_env.action_space.low,
+                self.gym_env.action_space.high,
+            )
+        return torch.tensor(
+            [self.gym_env.action_space.sample()], dtype=torch.int32, device=self.device
+        )
