@@ -4,14 +4,11 @@ import numpy as np
 import torch
 from rlvortex.envs.base_env import EnvWrapper
 from rlvortex.replay_buffer.ppo_replay_buffer import (
-    NpPPOReplayBuffer,
     TensorPPOReplayBuffer,
 )
 from rlvortex.policy.ppo_policy import BasePPOPolicy
 from rlvortex.trainer.base_trainer import BaseTrainer
-from rlvortex.utils.trainer_utils import v_debug
 from rlvortex.utils import vlogger
-from pdb import set_trace as fuck
 
 
 class NativePPOTrainer(BaseTrainer):
@@ -33,16 +30,16 @@ class NativePPOTrainer(BaseTrainer):
         gamma: float = 0.998,
         lam: float = 0.95,
         entropy_loss_coef=0.0,
-        max_grad_norm:Optional[float]=0.5,
+        max_grad_norm: Optional[float] = 0.5,
         val_loss_clip=False,
         desired_kl=None,
         update_break: bool = False,
         random_sampler: bool = False,
         trainer_dir: str = os.path.join(os.getcwd(), "ppo_trainers"),
         enable_tensorboard: bool = False,
-        save_freq: int = -1,  # if save_freg == -1, then disable save, if save_freq == 0, then save at the end of training,otherwise save every save_freq epochs
+        save_freq: int = -1,  # if save_freg == -1, then disable save, if save_freq == 0, then save at the end of training,otherwise save every save_freq epochs  # noqa: E501
         log_type: vlogger.LogType = vlogger.LogType.Screen,
-        device_id: int = -1,
+        device: torch.device = torch.device("cpu"),
         comment: str = "",
         seed: int = 19970314,
     ) -> None:
@@ -58,7 +55,7 @@ class NativePPOTrainer(BaseTrainer):
             log_type=log_type,
             comment=comment,
             seed=seed,
-            device_id=device_id,
+            device=device,
         )
         # store input parameters
         self.learning_iterations = learning_iterations
@@ -71,7 +68,7 @@ class NativePPOTrainer(BaseTrainer):
         self.gamma = gamma
         self.lam = lam
         self.entropy_loss_coef = entropy_loss_coef
-        self.max_grad_norm:Optional[float] = max_grad_norm
+        self.max_grad_norm: Optional[float] = max_grad_norm
         self.val_loss_clip = val_loss_clip
         self.desired_kl = desired_kl
         self.update_break = update_break
@@ -84,6 +81,7 @@ class NativePPOTrainer(BaseTrainer):
             observation_dim=self.env.observation_dim,
             action_dim=self.env.action_dim,
             random_sampler=self.random_sampler,
+            device=self.device,
         )
 
     def train(self, epochs: int):
@@ -116,7 +114,9 @@ class NativePPOTrainer(BaseTrainer):
                     self.append_eposide_rollout_info(ep_length=ep_len, ep_return=ep_ret)
                     (o, _), (ep_len, ep_ret) = self.env.reset(), (0, 0)
                 self.append_customized_tb_info(cache)
-            _, v, _ = self.policy.step(torch.as_tensor(o, dtype=torch.float32))
+            _, v, _ = self.policy.step(
+                torch.as_tensor(o, dtype=torch.float32, device=self.device)
+            )
             self.replay_buffer.compute_returns(v, self.gamma, self.lam)
             self.__update_policy()
             self._log_all(self.epoch)
@@ -211,7 +211,7 @@ class NativePPOTrainer(BaseTrainer):
                 LV=max[(Vθt−Vtarg)2,(clip(Vθt,Vθt−1−ε,Vθt−1+ε)−Vtarg)2]
                 Engstrom, Ilyas, et al., (2020) find no evidence that the value function loss clipping helps with the performance. Andrychowicz, et al. (2021) suggest value function loss clipping even hurts performance (decision C13, figure 43).
                 We implemented this detail because this work is more about high-fidelity reproduction of prior results.
-                """
+                """  # noqa: E501
                 if self.val_loss_clip:
                     values_clipped = old_val + (val - old_val).clamp(
                         -self.clip_ratio, self.clip_ratio
@@ -230,7 +230,7 @@ class NativePPOTrainer(BaseTrainer):
                     https://iclr-blog-track.github.io/2022/03/25/ppo-implementation-details/
                     approxkl: the approximate Kullback–Leibler divergence, measured by (-logratio).mean(), which corresponds to the k1 estimator in John Schulman’s blog post on approximating KL divergence. This blog post also suggests using an alternative estimator ((ratio - 1) - logratio).mean(), which is unbiased and has less variance.
 
-                    """
+                    """  # noqa: E501
                     if approx_kl_div > self.desired_kl * 1.5 and self.update_break:
                         break
                     if approx_kl_div > self.desired_kl * 2.0:
