@@ -1,4 +1,5 @@
 import torch
+import torch.backends.mps
 import numpy as np
 import random
 
@@ -11,6 +12,14 @@ def v_debug():
     pdb.set_trace()
 
 
+def get_available_device() -> torch.device:
+    if torch.cuda.is_available():
+        return torch.device("cuda")
+    if torch.backends.mps.is_available():
+        return torch.device("mps")
+    return torch.device("cpu")
+
+
 def set_global_random_seed(rd_seed: int = 314):
     random.seed(rd_seed)
     np.random.seed(rd_seed)
